@@ -14,15 +14,8 @@
 #ifndef BITMASK_H_
 #define BITMASK_H_
 
-#include "samtools/rdef.h"
-#ifdef R_CRAN
-#include <R.h>
-#else
-#define R_INLINE inline
-#define Rprintf printf
-#endif
-
 #include <stdint.h>
+#include "./samtools/rdef.h"
 
 // This checks whether this is compiled in 64 bit
 #if UINTPTR_MAX == 0xffffffffffffffff
@@ -36,7 +29,7 @@
 // 8 byte-sized fields are used
 // (Also used by gapSiteList)
 typedef unsigned long long  bitmap_type; 							// Size at least 64 bits (C99)
-const unsigned long long idx[]      ={0,8,16,24,32,40,48,56};
+const unsigned idx[]      ={0,8,16,24,32,40,48,56};
 const unsigned long  pat[]={
                            0xFF             , 0xFF00              , 0xFF0000          , 0xFF000000        ,
                            0xFF00000000     , 0xFF0000000000      , 0xFF000000000000  , 0xFF00000000000000
@@ -51,7 +44,7 @@ const unsigned long rpat[]={
                            };
 
 const unsigned bitmap_size=8;
-const int max_bitmap_index=7;
+const unsigned max_bitmap_index=7;
 // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 #else
 // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -59,7 +52,7 @@ const int max_bitmap_index=7;
 // 4 byte-sized fields are used
 // (Also used by gapSiteList)
 typedef unsigned long       bitmap_type;							// Size at least 32 bits (C99)
-const unsigned long idx[]      ={0,8,16,24};
+const unsigned idx[]      ={0,8,16,24};
 
 const unsigned long  pat[]={
                            0xFF             , 0xFF00              , 0xFF0000          , 0xFF000000
@@ -72,7 +65,7 @@ const unsigned long rpat[]={
                            };
 
 const unsigned bitmap_size=4;
-const int max_bitmap_index=3;
+const unsigned max_bitmap_index=3;
 // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 #endif
 
@@ -101,7 +94,7 @@ index_type bitmask_sumPos(const bitmap_type val)
 	index_type res=0;
 	unsigned i;
 	for(i=0;i<bitmap_size;++i)
-		res+=(index_type)(val>>idx[i])&0xFF;
+		res+=(val>>idx[i])&0xFF;
 	return res;
 }
 
@@ -226,7 +219,7 @@ void l_addVal(bitmap_type *map,const value_type val)
 			return;
 		if(val>byte_val)
 		{
-			l_insByte(map,val,(index_type)block);
+			l_insByte(map,val,block);
 			return;
 		}
 		--block;
@@ -540,13 +533,13 @@ static R_INLINE void l_zip(bitmap_type lhs, bitmap_type rhs, bitmap_type *res)
 	{
 		l_insByte(res,lByte,bitmap_size-1);
 		lblock=max_bitmap_index-1;
-		rblock=(int)max_bitmap_index;
+		rblock=max_bitmap_index;
 	}
 	else if(lByte<rByte)
 	{
 		l_insByte(res,rByte,bitmap_size-1);
 		rblock=max_bitmap_index-1;
-		lblock=(int)max_bitmap_index;
+		lblock=max_bitmap_index;
 	}
 	else
 	{
